Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(715)

Unified Diff: chrome/browser/ui/views/payments/payment_request_views_util.h

Issue 2668063003: [Web Payments] Add Cancel button to all sheets (Closed)
Patch Set: Address feedback about footer row creation. Created 3 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/views/payments/payment_request_views_util.h
diff --git a/chrome/browser/ui/views/payments/payment_request_views_util.h b/chrome/browser/ui/views/payments/payment_request_views_util.h
index 13e250614e9a4e19fa1678f90432b847426be79c..b00c97244b29559ae1d0499ec0d4d30bc6925998 100644
--- a/chrome/browser/ui/views/payments/payment_request_views_util.h
+++ b/chrome/browser/ui/views/payments/payment_request_views_util.h
@@ -50,18 +50,21 @@ std::unique_ptr<views::View> CreateSheetHeaderView(
// |header_view| is the view displayed on top of the dialog, containing title,
// (optional) back button, and close buttons.
// |content_view| is displayed between |header_view| and the pay/cancel buttons.
// The returned view takes ownership of |header_view| and |content_view|.
// +---------------------------+
// | HEADER VIEW |
// +---------------------------+
// | CONTENT |
// | VIEW |
// +---------------------------+
-// | | CANCEL | PAY |
+// | | CANCEL | PAY | <-- |buttons_view|
// +---------------------------+
std::unique_ptr<views::View> CreatePaymentView(
std::unique_ptr<views::View> header_view,
- std::unique_ptr<views::View> content_view);
+ std::unique_ptr<views::View> content_view,
+ std::unique_ptr<views::View> buttons_view);
// Represents formatting options for each of the different contexts in which an
// Address label may be displayed.
@@ -50,18 +50,21 @@ std::unique_ptr<views::View> CreateSheetHeaderView(
// (optional) back button, and close buttons.
// |content_view| is displayed between |header_view| and the pay/cancel buttons.
-// The returned view takes ownership of |header_view| and |content_view|.
+// |buttons_view| is clamped to the bottom of the containing view.
+// The returned view takes ownership of |header_view|, |content_view|, and
+// |buttons_view|.
// +---------------------------+
// | HEADER VIEW |

Powered by Google App Engine
This is Rietveld 408576698